==> buffybox_3.2.0+dfsg.orig.tar.xz: buffybox-3.2.0/lvgl/tests/test_images/stride_align1/LZ4/test_A1_LZ4_align1.c <==

#if defined(LV_LVGL_H_INCLUDE_SIMPLE)
#include "lvgl.h"
#elif defined(LV_BUILD_TEST)
#include "../lvgl.h"
#else
#include "lvgl/lvgl.h"
#endif


#ifndef LV_ATTRIBUTE_MEM_ALIGN
#define LV_ATTRIBUTE_MEM_ALIGN
#endif

#ifndef LV_ATTRIBUTE_IMG_DUST
#define LV_ATTRIBUTE_IMG_DUST
#endif

static const
LV_ATTRIBUTE_MEM_ALIGN LV_ATTRIBUTE_LARGE_CONST LV_ATTRIBUTE_IMG_DUST
uint8_t test_A1_LZ4_align1_map[] = {

    0x02,0x00,0x00,0x00,0x4f,0x01,0x00,0x00,0xc0,0x03,0x00,0x00,0x13,0xff,0x01,0x00,
    0x22,0xfe,0x00,0x01,0x00,0x12,0x80,0x07,0x00,0x23,0x00,0x02,0x08,0x00,0x0c,0x10,
    0x00,0x93,0x9f,0xff,0xe0,0x00,0x00,0x00,0x1f,0xff,0xf2,0x20,0x00,0x96,0x9f,0xff,
    0xe0,0x1f,0x80,0x00,0x10,0x00,0x12,0x10,0x00,0x66,0x7f,0xe0,0x18,0x17,0xff,0xd2,
    0x10,0x00,0x65,0xff,0xf0,0x3c,0x14,0x00,0x52,0x10,0x00,0x69,0xe1,0xff,0xf8,0x3c,
    0x15,0xff,0x10,0x00,0x36,0x18,0x15,0x01,0x10,0x00,0x6b,0xe3,0xff,0xfc,0x00,0x15,
    0x7d,0x10,0x00,0x19,0x45,0x10,0x00,0x39,0x3c,0x15,0x55,0x10,0x00,0x1b,0x7e,0x20,
    0x00,0x1b,0xff,0x40,0x00,0x18,0xff,0x60,0x00,0x4b,0xe1,0xff,0xf8,0xff,0x80,0x00,
    0x18,0xff,0xa0,0x00,0x49,0xe0,0xff,0xf0,0x7e,0xc0,0x00,0x36,0x7f,0xe0,0x3c,0xe0,
    0x00,0x57,0x80,0x00,0x00,0x1f,0x80,0x00,0x01,0x0c,0x20,0x01,0x0e,0x10,0x00,0x11,
    0x07,0x62,0x01,0x04,0x30,0x01,0x22,0x83,0xfc,0x09,0x01,0x04,0x60,0x01,0x2c,0x8f,
    0xff,0x10,0x00,0x02,0x42,0x00,0x05,0x20,0x00,0x1b,0x0f,0x10,0x00,0x21,0x07,0x80,
    0x12,0x00,0x04,0x20,0x00,0x58,0x8e,0x07,0xc0,0x3f,0xc0,0xb0,0x01,0x47,0x07,0xc0,
    0x3f,0xe0,0x10,0x00,0x92,0x81,0xff,0xc0,0x30,0xf0,0x00,0x00,0x52,0x22,0x67,0x00,
    0x22,0x00,0x87,0x10,0x00,0x05,0xe0,0x01,0x49,0x8f,0xff,0xc0,0x03,0x10,0x00,0x65,
    0x07,0xc0,0x3f,0xf0,0x0f,0x80,0x20,0x00,0x75,0x9f,0x07,0xc0,0x7f,0xf0,0x08,0xc0,
    0x40,0x00,0x76,0x9f,0x07,0xc0,0x78,0xf0,0x01,0xc0,0x20,0x00,0x56,0x0f,0xc0,0x70,
    0xf0,0x0f,0x10,0x00,0x66,0x8f,0xff,0xe0,0x79,0xf0,0x0c,0x30,0x00,0x66,0x8f,0xff,
    0xe0,0x7f,0xf8,0x0d,0x20,0x00,0x75,0x87,0xf3,0xe0,0x3e,0x78,0x0f,0xe0,0x50,0x00,
    0x02,0xde,0x00,0x06,0xd0,0x00,0x0c,0x10,0x00,0x11,0x9f,0x3e,0x01,0x16,0xe0,0x70,
    0x00,0x0f,0x10,0x00,0xbc,0x0c,0xf0,0x00,0x0f,0x10,0x00,0x0d,0x01,0xff,0x00,0xb0,
    0xff,0xff,0xff,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,

};

const lv_img_dsc_t test_A1_LZ4_align1 = {
  .header.magic = LV_IMAGE_HEADER_MAGIC,
  .header.cf = LV_COLOR_FORMAT_A1,
  .header.flags = 0 | LV_IMAGE_FLAGS_COMPRESSED,
  .header.w = 71,
  .header.h = 60,
  .header.stride = 16,
  .data_size = 347,
  .data = test_A1_LZ4_align1_map,
};

==> buffybox_3.4.2+dfsg.orig.tar.xz: buffybox-3.4.2+dfsg/lvgl/tests/test_images/stride_align1/LZ4/test_A1_LZ4_align1.c <==

#if defined(LV_LVGL_H_INCLUDE_SIMPLE)
#include "lvgl.h"
#elif defined(LV_LVGL_H_INCLUDE_SYSTEM)
#include <lvgl.h>
#elif defined(LV_BUILD_TEST)
#include "../lvgl.h"
#else
#include "lvgl/lvgl.h"
#endif

#ifndef LV_ATTRIBUTE_MEM_ALIGN
#define LV_ATTRIBUTE_MEM_ALIGN
#endif

#ifndef LV_ATTRIBUTE_TEST_A1_LZ4_ALIGN1
#define LV_ATTRIBUTE_TEST_A1_LZ4_ALIGN1
#endif

static const
LV_ATTRIBUTE_MEM_ALIGN LV_ATTRIBUTE_LARGE_CONST LV_ATTRIBUTE_TEST_A1_LZ4_ALIGN1
uint8_t test_A1_LZ4_align1_map[] = {

    0x02,0x00,0x00,0x00,0x4f,0x01,0x00,0x00,0xc0,0x03,0x00,0x00,0x13,0xff,0x01,0x00,
    0x22,0xfe,0x00,0x01,0x00,0x12,0x80,0x07,0x00,0x23,0x00,0x02,0x08,0x00,0x0c,0x10,
    0x00,0x93,0x9f,0xff,0xe0,0x00,0x00,0x00,0x1f,0xff,0xf2,0x20,0x00,0x96,0x9f,0xff,
    0xe0,0x1f,0x80,0x00,0x10,0x00,0x12,0x10,0x00,0x66,0x7f,0xe0,0x18,0x17,0xff,0xd2,
    0x10,0x00,0x65,0xff,0xf0,0x3c,0x14,0x00,0x52,0x10,0x00,0x69,0xe1,0xff,0xf8,0x3c,
    0x15,0xff,0x10,0x00,0x36,0x18,0x15,0x01,0x10,0x00,0x6b,0xe3,0xff,0xfc,0x00,0x15,
    0x7d,0x10,0x00,0x19,0x45,0x10,0x00,0x39,0x3c,0x15,0x55,0x10,0x00,0x1b,0x7e,0x20,
    0x00,0x1b,0xff,0x40,0x00,0x18,0xff,0x60,0x00,0x4b,0xe1,0xff,0xf8,0xff,0x80,0x00,
    0x18,0xff,0xa0,0x00,0x49,0xe0,0xff,0xf0,0x7e,0xc0,0x00,0x36,0x7f,0xe0,0x3c,0xe0,
    0x00,0x57,0x80,0x00,0x00,0x1f,0x80,0x00,0x01,0x0c,0x20,0x01,0x0e,0x10,0x00,0x11,
    0x07,0x62,0x01,0x04,0x30,0x01,0x22,0x83,0xfc,0x09,0x01,0x04,0x60,0x01,0x2c,0x8f,
    0xff,0x10,0x00,0x02,0x42,0x00,0x05,0x20,0x00,0x1b,0x0f,0x10,0x00,0x21,0x07,0x80,
    0x12,0x00,0x04,0x20,0x00,0x58,0x8e,0x07,0xc0,0x3f,0xc0,0xb0,0x01,0x47,0x07,0xc0,
    0x3f,0xe0,0x10,0x00,0x92,0x81,0xff,0xc0,0x30,0xf0,0x00,0x00,0x52,0x22,0x67,0x00,
    0x22,0x00,0x87,0x10,0x00,0x05,0xe0,0x01,0x49,0x8f,0xff,0xc0,0x03,0x10,0x00,0x65,
    0x07,0xc0,0x3f,0xf0,0x0f,0x80,0x20,0x00,0x75,0x9f,0x07,0xc0,0x7f,0xf0,0x08,0xc0,
    0x40,0x00,0x76,0x9f,0x07,0xc0,0x78,0xf0,0x01,0xc0,0x20,0x00,0x56,0x0f,0xc0,0x70,
    0xf0,0x0f,0x10,0x00,0x66,0x8f,0xff,0xe0,0x79,0xf0,0x0c,0x30,0x00,0x66,0x8f,0xff,
    0xe0,0x7f,0xf8,0x0d,0x20,0x00,0x75,0x87,0xf3,0xe0,0x3e,0x78,0x0f,0xe0,0x50,0x00,
    0x02,0xde,0x00,0x06,0xd0,0x00,0x0c,0x10,0x00,0x11,0x9f,0x3e,0x01,0x16,0xe0,0x70,
    0x00,0x0f,0x10,0x00,0xbc,0x0c,0xf0,0x00,0x0f,0x10,0x00,0x0d,0x01,0xff,0x00,0xb0,
    0xff,0xff,0xff,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,

};

const lv_image_dsc_t test_A1_LZ4_align1 = {
  .header = {
    .magic = LV_IMAGE_HEADER_MAGIC,
    .cf = LV_COLOR_FORMAT_A1,
    .flags = 0 | LV_IMAGE_FLAGS_COMPRESSED,
    .w = 71,
    .h = 60,
    .stride = 16,
    .reserved_2 = 0,
  },
  .data_size = sizeof(test_A1_LZ4_align1_map),
  .data = test_A1_LZ4_align1_map,
  .reserved = NULL,
};
